.. _examples:

Examples
========

The following examples illustrate the usage of pyDVL features.

.. toctree::
   :caption: Data valuation
   :titlesonly:
   :glob:

   shapley*
   least_core*

.. toctree::
   :caption: Influence function
   :titlesonly:
   :glob:

   influence*
